@@ -14,7 +14,7 @@ except ImportError:
 
 import logging
 
-from cqlengine.exceptions import CQLEngineException
+from cqlengine.exceptions import CQLEngineException, UndefinedKeyspaceException
 from cassandra import ConsistencyLevel
 from cqlengine.statements import BaseCQLStatement
 from cassandra.query import dict_factory
@@ -27,12 +27,14 @@ Host = namedtuple('Host', ['name', 'port'])
 
 cluster = None
 session = None
+lazy_connect_args = None
 default_consistency_level = None
 
 def setup(
         hosts,
-        default_keyspace=None,
+        default_keyspace,
         consistency=ConsistencyLevel.ONE,
+        lazy_connect=False,
         **kwargs):
     """
     Records the hosts and connects to one of them
@@ -43,23 +45,36 @@ def setup(
     :type default_keyspace: str
     :param consistency: The global consistency level
     :type consistency: int
+    :param lazy_connect: True if should not connect until first use
+    :type lazy_connect: bool
     """
-    global cluster, session, default_consistency_level
+    global cluster, session, default_consistency_level, lazy_connect_args
 
     if 'username' in kwargs or 'password' in kwargs:
         raise CQLEngineException("Username & Password are now handled by using the native driver's auth_provider")
 
-    if default_keyspace:
-        from cqlengine import models
-        models.DEFAULT_KEYSPACE = default_keyspace
+    if not default_keyspace:
+        raise UndefinedKeyspaceException()
+
+    from cqlengine import models
+    models.DEFAULT_KEYSPACE = default_keyspace
 
     default_consistency_level = consistency
+    if lazy_connect:
+        lazy_connect_args = (hosts, default_keyspace, consistency, kwargs)
+        return
+
     cluster = Cluster(hosts, **kwargs)
     session = cluster.connect()
     session.row_factory = dict_factory
 
 def execute(query, params=None, consistency_level=None):
 
+    if not session:
+        raise CQLEngineException("It is required to setup() cqlengine before executing queries")
+
+    handle_lazy_connect()
+
     if consistency_level is None:
         consistency_level = default_consistency_level
 
@@ -75,6 +90,7 @@ def execute(query, params=None, consistency_level=None):
         query = SimpleStatement(query, consistency_level=consistency_level)
 
 
+
     params = params or {}
     result = session.execute(query, params)
 
@@ -82,7 +98,16 @@ def execute(query, params=None, consistency_level=None):
 
 
 def get_session():
+    handle_lazy_connect()
     return session
 
 def get_cluster():
+    handle_lazy_connect()
     return cluster
+
+def handle_lazy_connect():
+    global lazy_connect_args
+    if lazy_connect_args:
+        hosts, default_keyspace, consistency, kwargs = lazy_connect_args
+        lazy_connect_args = None
+        setup(hosts, default_keyspace, consistency, **kwargs)
